(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 9.5.00 by Jan
 *
 * Time-stamp: <Monday 24 June 02 9:59:40 tews@ithif51>
 *
 * the ccsl morphisms
 *
 * $Id: morphism_theory.mli,v 1.5 2002/07/03 12:01:15 tews Exp $
 *
 *)

open Classtypes

class ccsl_morphism_theory
  : ccsl_iface_type ->  ccsl_class_theory_type 

class ccsl_morphism_rewrite_theory
  : ccsl_iface_type ->  ccsl_class_theory_type 

class ccsl_finality_theory
  : ccsl_iface_type ->  ccsl_class_theory_type 

class ccsl_finality_bisim_theory
  : ccsl_iface_type ->  ccsl_class_theory_type 

class ccsl_map_struct_theory
  : ccsl_iface_type ->  ccsl_class_theory_type 

class ccsl_map_theory
  : ccsl_iface_type ->  ccsl_class_theory_type 



(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)

